@@ -1,6 +1,6 @@
 import pycbc.catalog
 
-c = pycbc.catalog.Catalog()
+c = pycbc.catalog.Catalog(source='gwtc-2')
 
 # Names of mergers in the catalog
 print(c.names)
