@@ -141,6 +141,13 @@ except ImportError:
 # platforms (mac) that are silly and don't use the standard gcc.
 if sys.platform == 'darwin':
     HAVE_OMP = False
+
+    # MacosX after python3.7 switched to 'spawn', however, this does not
+    # preserve common state information which we have relied on when using
+    # multiprocessing based pools.
+    import multiprocessing
+    if hasattr(multiprocessing, 'set_start_method'):
+        multiprocessing.set_start_method('fork')
 else:
     HAVE_OMP = True
 
