@@ -17,6 +17,7 @@ This modules provides classes for evaluating distributions with bounds.
 """
 
 import warnings
+import numpy
 from six.moves.configparser import Error
 from pycbc import boundaries
 from pycbc import VARARGS_DELIM
@@ -315,6 +316,13 @@ class BoundedDist(object):
             updated[param] = self._cdfinv_param(param, kwds[param])
         return updated
 
+    def rvs(self, size=1, **kwds):
+        "Draw random value"
+        draw = {}
+        for param in self.params:
+            draw[param] = numpy.random.uniform(0, 1, size=size)
+        return self.cdfinv(**draw)
+
     @classmethod
     def from_config(cls, cp, section, variable_args, bounds_required=False):
         """Returns a distribution based on a configuration file. The parameters
