@@ -50,38 +50,6 @@ class UniformLog10(uniform.Uniform):
         upper_bound = numpy.log10(self._bounds[param][1])
         return 10. ** ((upper_bound - lower_bound) * value + lower_bound)
 
-    def rvs(self, size=1, param=None):
-        """Gives a set of random values drawn from this distribution.
-
-        Parameters
-        ----------
-        size : {1, int}
-            The number of values to generate; default is 1.
-        param : {None, string}
-            If provided, will just return values for the given parameter.
-            Otherwise, returns random values for each parameter.
-
-        Returns
-        -------
-        structured array
-            The random values in a numpy structured array. If a param was
-            specified, the array will only have an element corresponding to the
-            given parameter. Otherwise, the array will have an element for each
-            parameter in self's params.
-        """
-
-        if param is not None:
-            dtype = [(param, float)]
-        else:
-            dtype = [(p, float) for p in self.params]
-        arr = numpy.zeros(size, dtype=dtype)
-        for (p,_) in dtype:
-            log_high = numpy.log10(self._bounds[p][0])
-            log_low = numpy.log10(self._bounds[p][1])
-            arr[p] = 10.0**(numpy.random.uniform(log_low, log_high, size=size))
-        return arr
-
-
     def _pdf(self, **kwargs):
         """Returns the pdf at the given values. The keyword arguments must
         contain all of parameters in self's params. Unrecognized arguments are
