@@ -49,10 +49,11 @@ def strain_from_cli_multi_ifos(*args, **kwargs):
         try:
             return strain.from_cli_multi_ifos(*args, **kwargs)
         except RuntimeError as e:
+            exception = e
             count += 1
             sleep(10)
     # if get to here, we've tries 3 times and still got an error, so exit
-    raise RuntimeError(e)
+    raise exception
 
 
 #
@@ -129,7 +130,7 @@ def create_data_parser():
                          help='Where to look for DQ information. If "any" '
                               '(the default) will first try GWOSC, then '
                               'dqsegdb.')
-    dqgroup.add_argument('--dq-server', default='segments.ligo.org',
+    dqgroup.add_argument('--dq-server', default='https://segments.ligo.org',
                          help='The server to use for dqsegdb.')
     dqgroup.add_argument('--veto-definer', default=None,
                          help='Path to a veto definer file that defines '
