@@ -136,6 +136,7 @@ def get_libpath_from_dirlist(libname, dirs):
             for libfile in os.listdir(nextdir):
                 if fnmatch.fnmatch(libfile,'lib'+libname+'.so*') or \
                         fnmatch.fnmatch(libfile,'lib'+libname+'.dylib*') or \
+                        fnmatch.fnmatch(libfile,'lib'+libname+'.*.dylib*') or \
                         fnmatch.fnmatch(libfile,libname+'.dll') or \
                         fnmatch.fnmatch(libfile,'cyg'+libname+'-*.dll'):
                     possible.append(libfile)
@@ -165,13 +166,14 @@ def get_ctypes_library(libname, packages, mode=None):
         libdirs += pkg_config_libdirs(packages)
     except ValueError:
         pass
-    # Next, if we are in a virtual environment, search inside its '/lib'
-    if "VIRTUAL_ENV" in os.environ:
-        libdirs.append(os.path.join(os.environ["VIRTUAL_ENV"], "lib"))
+    # We might be using conda/pip/virtualenv or some combination. This can
+    # leave lib files in a directory that LD_LIBRARY_PATH or pkg_config
+    # can miss.
+    libdirs.append(os.path.join(sys.prefix, "lib"))
 
-    # Note that the function below can accept an empty list for libdirs, in which case
-    # it will return None
-    fullpath = get_libpath_from_dirlist(libname,libdirs)
+    # Note that the function below can accept an empty list for libdirs, in
+    # which case it will return None
+    fullpath = get_libpath_from_dirlist(libname, libdirs)
 
     if fullpath is None:
         # This won't actually return a full-path, but it should be something
@@ -185,4 +187,4 @@ def get_ctypes_library(libname, packages, mode=None):
         if mode is None:
             return ctypes.CDLL(fullpath)
         else:
-            return ctypes.CDLL(fullpath,mode=mode)
+            return ctypes.CDLL(fullpath, mode=mode)
