@@ -3,7 +3,8 @@ from pycbc.waveform.utils import *
 from pycbc.waveform.bank import *
 from pycbc.waveform.ringdown import *
 from pycbc.waveform.parameters import *
-
+from pycbc.waveform.waveform_modes import (get_td_waveform_modes,
+                                           get_fd_waveform_modes)
 from pycbc.waveform.plugin import (retrieve_waveform_plugins,
                                    add_custom_waveform,
                                    add_length_estimator)
