@@ -25,6 +25,7 @@
 """
 This module provides classes that describe banks of waveforms
 """
+import sys
 import types
 import logging
 import os.path
@@ -337,7 +338,13 @@ class TemplateBank(object):
         # (if anything was in the file)
         if approximant is not None:
             # get the approximant for each template
-            apprxs = self.parse_approximant(approximant)
+            # FIXME: Remove if block once python2 is retired
+            if sys.version_info >= (3, 0):
+                dtype = h5py.string_dtype(encoding='utf-8')
+                apprxs = np.array(self.parse_approximant(approximant),
+                                  dtype=dtype)
+            else:
+                apprxs = self.parse_approximant(approximant)
             if 'approximant' not in self.table.fieldnames:
                 self.table = self.table.add_fields(apprxs, 'approximant')
             else:
@@ -475,14 +482,19 @@ class TemplateBank(object):
         tau0_temp, _ = pycbc.pnutils.mass1_mass2_to_tau0_tau3(m1, m2, fref)
         indices = []
 
+        sort = tau0_temp.argsort()
+        tau0_temp = tau0_temp[sort]
+
         for inj in injection_parameters:
             tau0_inj, _ = \
                 pycbc.pnutils.mass1_mass2_to_tau0_tau3(inj.mass1, inj.mass2,
                                                        fref)
-            inj_indices = np.where(abs(tau0_temp - tau0_inj) <= threshold)[0]
+            lid = np.searchsorted(tau0_temp, tau0_inj - threshold)
+            rid = np.searchsorted(tau0_temp, tau0_inj + threshold)
+            inj_indices = sort[lid:rid]
             indices.append(inj_indices)
-            indices_combined = np.concatenate(indices)
 
+        indices_combined = np.concatenate(indices)
         indices_unique= np.unique(indices_combined)
         self.table = self.table[indices_unique]
 
