@@ -148,6 +148,7 @@ def select_generic_executable(workflow, exe_tag):
         'repop_coinc_expfit'       : SQLInOutExecutable,
         'ligolw_cbc_dbinjfind'         : SQLInOutExecutable,
         'lalapps_inspinj'          : LalappsInspinjExecutable,
+        'pycbc_create_injections'  : PyCBCCreateInjectionsExecutable,
         'pycbc_dark_vs_bright_injections' : PycbcDarkVsBrightInjectionsExecutable,
         'pycbc_timeslides'         : PycbcTimeslidesExecutable,
         'pycbc_compute_durations'  : ComputeDurationsExecutable,
@@ -1504,6 +1505,22 @@ class GstlalSummaryPage(Executable):
             workflow._adag.addDependency(dep)
         return node
 
+class PyCBCCreateInjectionsExecutable(Executable):
+    """
+    The class used to create jobs for the lalapps_inspinj Executable.
+    """
+    current_retention_level = Executable.FINAL_RESULT
+    file_input_options = ['--config-files']
+    def create_node(self, segment, tags=None):
+        if tags is None:
+            tags = []
+        node = Node(self)
+        node.new_output_file_opt(segment, '.hdf', '--output-file',
+                                 store_file=self.retain_files, tags=tags)
+        node.add_opt('--gps-start-time', int_gps_time_to_str(segment[0]))
+        node.add_opt('--gps-end-time', int_gps_time_to_str(segment[1]))
+        return node
+
 class LalappsInspinjExecutable(Executable):
     """
     The class used to create jobs for the lalapps_inspinj Executable.
